==> Dip-0.91.5.zip: Dip-0.91.5/Dip/src/config_dip_default.h <==
//===========================================================================//
// This file is part of the DIP Solver Framework.                            //
//                                                                           //
// DIP is distributed under the Eclipse Public License as part of the        //
// COIN-OR repository (http://www.coin-or.org).                              //
//                                                                           //
// Author: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)       //
//                                                                           //
// Conceptual Design: Matthew Galati, SAS Institute Inc.                     //
//                    Ted Ralphs, Lehigh University                          //
//                                                                           //
// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, Ted Ralphs    //
// All Rights Reserved.                                                      //
//===========================================================================//

/***************************************************************************/
/*           HERE DEFINE THE PROJECT SPECIFIC PUBLIC MACROS                */
/*    These are only in effect in a setting that doesn't use configure     */
/***************************************************************************/

/* Version number of project */
#define DIP_VERSION "0.91.5"

/* Major Version number of project */
#define DIP_VERSION_MAJOR 0

/* Minor Version number of project */
#define DIP_VERSION_MINOR 91

/* Release Version number of project */
#define DIP_VERSION_RELEASE 5

==> Dip-0.92.1.zip: Dip-0.92.1/Dip/src/config_dip_default.h <==
//===========================================================================//
// This file is part of the DIP Solver Framework.                            //
//                                                                           //
// DIP is distributed under the Eclipse Public License as part of the        //
// COIN-OR repository (http://www.coin-or.org).                              //
//                                                                           //
// Authors: Matthew Galati, SAS Institute Inc. (matthew.galati@sas.com)      //
//          Ted Ralphs, Lehigh University (ted@lehigh.edu)                   //
//          Jiadong Wang, Lehigh University (jiw408@lehigh.edu)              //
//                                                                           //
// Copyright (C) 2002-2015, Lehigh University, Matthew Galati, Ted Ralphs    //
// All Rights Reserved.                                                      //
//===========================================================================//

/***************************************************************************/
/*           HERE DEFINE THE PROJECT SPECIFIC PUBLIC MACROS                */
/*    These are only in effect in a setting that doesn't use configure     */
/***************************************************************************/

/* Version number of project */
#define DIP_VERSION "0.92.1"

/* Major Version number of project */
#define DIP_VERSION_MAJOR 0

/* Minor Version number of project */
#define DIP_VERSION_MINOR 92

/* Release Version number of project */
#define DIP_VERSION_RELEASE 1

/* Define to 1 if the Clp package is available */
#define DIP_HAS_CLP 1

/* Define to 1 if the Cbc package is available */
#define DIP_HAS_CBC 1
